@@ -24,13 +24,19 @@
 
 package picard.analysis;
 
+import org.broadinstitute.barclay.help.DocumentedFeature;
 import picard.metrics.MultilevelMetrics;
+import picard.util.help.HelpConstants;
 
 /**
  * High level metrics about the alignment of reads within a SAM file, produced by
  * the CollectAlignmentSummaryMetrics program and usually stored in a file with
  * the extension ".alignment_summary_metrics".
  */
+@DocumentedFeature(
+        groupName = HelpConstants.DOC_CAT_METRICS,
+        groupSummary = HelpConstants.DOC_CAT_METRICS_SUMMARY,
+        summary = "Alignment metrics")
 public class AlignmentSummaryMetrics extends MultilevelMetrics {
     public enum Category {UNPAIRED, FIRST_OF_PAIR, SECOND_OF_PAIR, PAIR}
 
@@ -133,7 +139,12 @@ public class AlignmentSummaryMetrics extends MultilevelMetrics {
     /** The standard deviation of the read lengths. Computed using all read lengths including clipped bases. */
     public double SD_READ_LENGTH;
 
-    /** The median read length. Computed using all read lengths including clipped bases. */
+    /**
+     * The median read length of the set of reads examined.  When looking at the data for a single lane with
+     * equal length reads this number is just the read length.  When looking at data for merged lanes with
+     * differing read lengths this is the median read length of all reads. Computed using all bases in reads,
+     * including clipped bases.
+     */
     public double MEDIAN_READ_LENGTH;
 
     /**
@@ -149,6 +160,13 @@ public class AlignmentSummaryMetrics extends MultilevelMetrics {
     /** The maximum read length. Computed using all read lengths including clipped bases. */
     public double MAX_READ_LENGTH;
 
+    /**
+     * The mean aligned read length of the set of reads examined.  When looking at the data for a single lane with
+     * equal length reads this number is just the read length.  When looking at data for merged lanes with
+     * differing read lengths this is the mean read length of all reads. Clipped bases are not counted.
+     */
+    public double MEAN_ALIGNED_READ_LENGTH;
+
     /**
      * The number of aligned reads whose mate pair was also aligned to the reference.
      */
