@@ -99,7 +99,7 @@ public class CalculateFingerprintMetrics extends CommandLineProgram {
     public File OUTPUT;
 
     @Argument(shortName = "H", doc = "The file lists a set of SNPs, optionally arranged in high-LD blocks, to be used for fingerprinting. See " +
-            "https://software.broadinstitute.org/gatk/documentation/article?id=9526 for details.")
+            "https://gatk.broadinstitute.org/hc/en-us/articles/360035531672-Haplotype-map-format for details.")
     public File HAPLOTYPE_MAP;
 
     @Argument(doc = "Specificies which data-type should be used as the basic unit. Fingerprints from readgroups can " +
