@@ -27,7 +27,6 @@ package picard.fingerprint;
 
 import org.broadinstitute.barclay.argparser.Argument;
 import org.broadinstitute.barclay.argparser.CommandLineProgramProperties;
-import org.broadinstitute.barclay.help.DocumentedFeature;
 import picard.cmdline.programgroups.DiagnosticsAndQCProgramGroup;
 
 import java.io.File;
@@ -42,16 +41,14 @@ import java.util.List;
  *
  * @deprecated 6/6/2017 Use {@link CrosscheckFingerprints} instead.
  */
-@DocumentedFeature
 @CommandLineProgramProperties(
-        summary = "DEPRECATED: USE CrosscheckFingerprints. Checks if all read groups within a set of BAM files appear to come from the same individual",
-        oneLineSummary = "DEPRECATED: USE CrosscheckFingerprints. Checks if all read groups appear to come from the same individual.",
+        summary = "DEPRECATED: USE CrosscheckFingerprints.",
+        oneLineSummary = "DEPRECATED: USE CrosscheckFingerprints. ",
         programGroup = DiagnosticsAndQCProgramGroup.class
 )
 @Deprecated
 public class CrosscheckReadGroupFingerprints extends CrosscheckFingerprints {
 
-
     @Argument(doc = "Instead of producing the normal comparison of read-groups, roll fingerprints up to the sample level " +
             "and print out a sample x sample matrix with LOD scores.")
     public boolean CROSSCHECK_SAMPLES = false;
