@@ -24,10 +24,15 @@
 
 package picard.sam;
 
+import htsjdk.samtools.SAMReadGroupRecord;
+import htsjdk.samtools.SAMRecord;
 import htsjdk.samtools.util.Histogram;
 import org.broadinstitute.barclay.help.DocumentedFeature;
 import picard.analysis.MergeableMetricBase;
 import picard.util.help.HelpConstants;
+import picard.sam.markduplicates.util.AbstractMarkDuplicatesCommandLineProgram;
+import picard.util.MathUtil;
+import java.util.List;
 
 /**
  * Metrics that are calculated during the process of marking duplicates
@@ -236,4 +241,36 @@ public class DuplicationMetrics extends MergeableMetricBase {
             System.out.println(bin.getId() + "\t" + bin.getValue());
         }
     }
+
+    /**
+     * Adds duplicated read to the metrics
+     */
+    public void addDuplicateReadToMetrics(final SAMRecord rec) {
+        // only update duplicate counts for "decider" reads, not tag-a-long reads
+        if (!rec.isSecondaryOrSupplementary() && !rec.getReadUnmappedFlag()) {
+            // Update the duplication metrics
+            if (!rec.getReadPairedFlag() || rec.getMateUnmappedFlag()) {
+                ++UNPAIRED_READ_DUPLICATES;
+
+            } else {
+                ++READ_PAIR_DUPLICATES;// will need to be divided by 2 at the end
+            }
+        }
+    }
+
+    /**
+     * Adds a read to the metrics
+     */
+    public void addReadToLibraryMetrics(final SAMRecord rec) {
+        // First bring the simple metrics up to date
+        if (rec.getReadUnmappedFlag()) {
+            ++UNMAPPED_READS;
+        } else if (rec.isSecondaryOrSupplementary()) {
+            ++SECONDARY_OR_SUPPLEMENTARY_RDS;
+        } else if (!rec.getReadPairedFlag() || rec.getMateUnmappedFlag()) {
+            ++UNPAIRED_READS_EXAMINED;
+        } else {
+            ++READ_PAIRS_EXAMINED; // will need to be divided by 2 at the end
+        }
+    }
 }
