@@ -28,14 +28,9 @@ import htsjdk.samtools.SAMRecord;
 import htsjdk.samtools.util.CollectionUtil;
 import htsjdk.samtools.util.SequenceUtil;
 import htsjdk.samtools.util.StringUtil;
+import htsjdk.samtools.util.Tuple;
 
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Comparator;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.TreeMap;
+import java.util.*;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.stream.Stream;
 
@@ -64,7 +59,7 @@ public class AdapterMarker {
 
     // This is AtomicReference because one thread could be matching adapters while the threshold has been crossed in another
     // thread and the array is being replaced.
-    private final AtomicReference<AdapterPair[]> adapters = new AtomicReference<AdapterPair[]>();
+    private final AtomicReference<AdapterPair[]> adapters = new AtomicReference<>();
 
     // All the members below are only accessed within a synchronized block.
     private boolean thresholdReached = false;
@@ -74,8 +69,10 @@ public class AdapterMarker {
     //Store all the sam records we have seen prior to choosing an adapter so that we can go back and fix the ones
     //that have clipping tags for adapters that were not chosen.
     private Map<AdapterPair, List<SAMRecord>> preAdapterPrunedRecords = new HashMap<>();
+
     /**
      * Truncates adapters to DEFAULT_ADAPTER_LENGTH
+     *
      * @param originalAdapters These should be in order from longest & most likely to shortest & least likely.
      */
     public AdapterMarker(final AdapterPair... originalAdapters) {
@@ -83,7 +80,7 @@ public class AdapterMarker {
     }
 
     /**
-     * @param adapterLength Truncate adapters to this length.
+     * @param adapterLength    Truncate adapters to this length.
      * @param originalAdapters These should be in order from longest & most likely to shortest & least likely.
      */
     public AdapterMarker(final int adapterLength, final AdapterPair... originalAdapters) {
@@ -123,6 +120,7 @@ public class AdapterMarker {
 
     /**
      * When this number of adapters have been matched, discard the least-frequently matching ones.
+     *
      * @param thresholdForSelectingAdaptersToKeep set to -1 to never discard any adapters.
      */
     public synchronized AdapterMarker setThresholdForSelectingAdaptersToKeep(final int thresholdForSelectingAdaptersToKeep) {
@@ -135,7 +133,6 @@ public class AdapterMarker {
     }
 
     /**
-     *
      * @param minSingleEndMatchBases When marking a single-end read, adapter must match at least this many bases.
      */
     public synchronized AdapterMarker setMinSingleEndMatchBases(final int minSingleEndMatchBases) {
@@ -148,7 +145,6 @@ public class AdapterMarker {
     }
 
     /**
-     *
      * @param minPairMatchBases When marking a paired-end read, adapter must match at least this many bases.
      */
     public synchronized AdapterMarker setMinPairMatchBases(final int minPairMatchBases) {
@@ -186,6 +182,16 @@ public class AdapterMarker {
         return adapterTrimIlluminaSingleRead(read, minSingleEndMatchBases, maxSingleEndErrorRate);
     }
 
+    /**
+     * Return the adapter to be trimmed from a read represented as an array of bytes[]
+     * @param read The byte array of read data
+     * @param templateIndex The paired index of the reads (1 or 2, 1 for single ended reads)
+     * @return The adapter pair that matched the read and its index in the read.
+     */
+    public Tuple<AdapterPair, Integer> findAdapterPairAndIndexForSingleRead(final byte[] read, final int templateIndex) {
+        return findAdapterPairAndIndexForSingleRead(read, minSingleEndMatchBases, maxSingleEndErrorRate, templateIndex);
+    }
+
     public AdapterPair adapterTrimIlluminaPairedReads(final SAMRecord read1, final SAMRecord read2) {
         return adapterTrimIlluminaPairedReads(read1, read2, minPairMatchBases, maxPairErrorRate);
     }
@@ -199,13 +205,36 @@ public class AdapterMarker {
         return ret;
     }
 
+    /**
+     * Return the adapter to be trimmed from a read represented as an array of bytes[]
+     * @param read The byte array of read data
+     * @param minMatchBases The minimum number of base matches required for adapter matching
+     * @param maxErrorRate The maximum error rate allowed for adapter matching
+     * @param templateIndex The paired index of the reads (1 or 2, 1 for single ended reads)
+     * @return The adapter pair that matched the read and its index in the read or null.
+     */
+    public Tuple<AdapterPair, Integer> findAdapterPairAndIndexForSingleRead(final byte[] read,
+                                                    final int minMatchBases,
+                                                    final double maxErrorRate,
+                                                    int templateIndex) {
+        final Tuple<AdapterPair, Integer> ret = ClippingUtility.findAdapterPairAndIndexForSingleRead(read,
+                minMatchBases,
+                maxErrorRate,
+                templateIndex,
+                adapters.get());
+        if (ret != null && !thresholdReached) {
+            tallyFoundAdapter(ret.a, false);
+        }
+        return ret;
+    }
+
     private void tallyAndFixAdapters(AdapterPair ret, SAMRecord... reads) {
         if (ret != null && !thresholdReached) {
-            if(!preAdapterPrunedRecords.containsKey(ret)) {
+            if (!preAdapterPrunedRecords.containsKey(ret)) {
                 preAdapterPrunedRecords.put(ret, new ArrayList<>());
             }
             Arrays.stream(reads).forEach(read -> preAdapterPrunedRecords.get(ret).add(read));
-            tallyFoundAdapter(ret);
+            tallyFoundAdapter(ret, true);
         }
     }
 
@@ -213,13 +242,15 @@ public class AdapterMarker {
      * Overrides defaults for minMatchBases and maxErrorRate
      */
     public AdapterPair adapterTrimIlluminaPairedReads(final SAMRecord read1, final SAMRecord read2,
-                                                             final int minMatchBases, final double maxErrorRate) {
+                                                      final int minMatchBases, final double maxErrorRate) {
         final AdapterPair ret = ClippingUtility.adapterTrimIlluminaPairedReads(read1, read2, minMatchBases, maxErrorRate, adapters.get());
         tallyAndFixAdapters(ret, read1, read2);
         return ret;
     }
 
-    /** For unit testing only */
+    /**
+     * For unit testing only
+     */
     AdapterPair[] getAdapters() {
         return adapters.get();
     }
@@ -245,7 +276,7 @@ public class AdapterMarker {
     /**
      * Keep track of every time an adapter is found, until it is time to prune the list of adapters.
      */
-    private void tallyFoundAdapter(final AdapterPair foundAdapter) {
+    private void tallyFoundAdapter(final AdapterPair foundAdapter, final boolean fixPreviousRecords) {
         // If caller does not want adapter pruning, do nothing.
         if (thresholdForSelectingAdaptersToKeep < 1) return;
         synchronized (this) {
@@ -289,7 +320,9 @@ public class AdapterMarker {
                 // Replace the existing list with the pruned list.
                 thresholdReached = true;
                 adapters.set(bestAdapters.toArray(new AdapterPair[bestAdapters.size()]));
-                fixAlreadySeenReads();
+                if (fixPreviousRecords) {
+                    fixAlreadySeenReads();
+                }
             }
         }
     }
@@ -309,7 +342,7 @@ public class AdapterMarker {
     private static final class TruncatedAdapterPair implements AdapterPair {
         String name;
         final String fivePrime, threePrime, fivePrimeReadOrder;
-        final byte[]  fivePrimeBytes, threePrimeBytes, fivePrimeReadOrderBytes;
+        final byte[] fivePrimeBytes, threePrimeBytes, fivePrimeReadOrderBytes;
 
         private TruncatedAdapterPair(final String name, final String threePrimeReadOrder, final String fivePrimeReadOrder) {
             this.name = name;
@@ -321,16 +354,41 @@ public class AdapterMarker {
             this.fivePrimeBytes = StringUtil.stringToBytes(this.fivePrime);
         }
 
-        public String get3PrimeAdapter(){ return threePrime; }
-        public String get5PrimeAdapter(){ return fivePrime; }
-        public String get3PrimeAdapterInReadOrder(){ return threePrime; }
-        public String get5PrimeAdapterInReadOrder() { return fivePrimeReadOrder; }
-        public byte[] get3PrimeAdapterBytes() { return threePrimeBytes; }
-        public byte[] get5PrimeAdapterBytes() { return fivePrimeBytes; }
-        public byte[] get3PrimeAdapterBytesInReadOrder() { return threePrimeBytes; }
-        public byte[] get5PrimeAdapterBytesInReadOrder()  { return fivePrimeReadOrderBytes; }
+        public String get3PrimeAdapter() {
+            return threePrime;
+        }
 
-        public String getName() { return this.name; }
+        public String get5PrimeAdapter() {
+            return fivePrime;
+        }
+
+        public String get3PrimeAdapterInReadOrder() {
+            return threePrime;
+        }
+
+        public String get5PrimeAdapterInReadOrder() {
+            return fivePrimeReadOrder;
+        }
+
+        public byte[] get3PrimeAdapterBytes() {
+            return threePrimeBytes;
+        }
+
+        public byte[] get5PrimeAdapterBytes() {
+            return fivePrimeBytes;
+        }
+
+        public byte[] get3PrimeAdapterBytesInReadOrder() {
+            return threePrimeBytes;
+        }
+
+        public byte[] get5PrimeAdapterBytesInReadOrder() {
+            return fivePrimeReadOrderBytes;
+        }
+
+        public String getName() {
+            return this.name;
+        }
 
         public void setName(final String name) {
             this.name = name;
