@@ -23,27 +23,39 @@
  */
 package picard.sam;
 
+import htsjdk.io.IOPath;
 import htsjdk.samtools.*;
 import htsjdk.samtools.util.CloserUtil;
+import htsjdk.utils.ValidationUtils;
 import org.broadinstitute.barclay.argparser.CommandLineException;
+import org.broadinstitute.http.nio.utils.Utils;
 import org.testng.Assert;
 import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
 import picard.PicardException;
 import picard.cmdline.CommandLineProgram;
 import picard.cmdline.CommandLineProgramTest;
-import picard.cmdline.PicardCommandLine;
+import picard.nio.PicardBucketUtils;
+import picard.nio.PicardHtsPath;
+import picard.nio.PicardIOUtils;
+import picard.util.GCloudTestUtils;
+import picard.util.TabbedInputParser;
+import picard.util.TabbedTextFileWithHeaderParser;
 
 import java.io.File;
+import java.io.IOException;
 import java.io.PrintWriter;
 import java.nio.file.Files;
+import java.nio.file.Path;
 import java.nio.file.Paths;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.stream.Collectors;
 
 /**
  * Created by IntelliJ IDEA.
@@ -53,21 +65,24 @@ import java.util.Map;
  * To change this template use File | Settings | File Templates.
  */
 public class RevertSamTest extends CommandLineProgramTest {
-    private static final String basicSamToRevert = "testdata/picard/sam/revert_sam_basic.sam";
-    private static final String sampleLibraryOverrideSam = "testdata/picard/sam/revert_sam_sample_library_override.sam";
-    private static final File validOutputMap = new File("testdata/picard/sam/revert_sam_valid_output_map.txt");
-    private static final File nonExistentOutputMap = new File("testdata/picard/sam/revert_sam_does_not_exist.txt");
-    private static final File badHeaderOutputMap = new File("testdata/picard/sam/revert_sam_bad_header_output_map.txt");
+    private final static String DEFAULT_CLOUD_TEST_OUTPUT_RELATIVE_PATH = "test/RevertSam/";
+    private final static PicardHtsPath DEFAULT_CLOUD_TEST_OUTPUT_DIR = PicardHtsPath.resolve(GCloudTestUtils.TEST_OUTPUT_DEFAULT_GCLOUD, DEFAULT_CLOUD_TEST_OUTPUT_RELATIVE_PATH);
+    public static final String REVERT_SAM_LOCAL_TEST_DATA_DIR = "testdata/picard/sam/RevertSam/";
+    private static final String basicSamToRevert = REVERT_SAM_LOCAL_TEST_DATA_DIR + "revert_sam_basic.sam";
+    private static final String sampleLibraryOverrideSam = REVERT_SAM_LOCAL_TEST_DATA_DIR + "revert_sam_sample_library_override.sam";
+    private static final File validOutputMap = new File(REVERT_SAM_LOCAL_TEST_DATA_DIR + "revert_sam_valid_output_map.txt");
+    private static final File nonExistentOutputMap = new File(REVERT_SAM_LOCAL_TEST_DATA_DIR + "revert_sam_does_not_exist.txt");
+    private static final File badHeaderOutputMap = new File(REVERT_SAM_LOCAL_TEST_DATA_DIR + "revert_sam_bad_header_output_map.txt");
     private static final File samTestData = new File("testdata/picard/sam");
-    private static final File writablePath = new File("testdata/picard/sam/revert_sam_writable.bam");
+    private static final File writablePath = new File(REVERT_SAM_LOCAL_TEST_DATA_DIR + "revert_sam_writable.bam");
     private static final File referenceFasta = new File("testdata/picard/reference/test.fasta");
-    private static final String singleEndSamToRevert = "testdata/picard/sam/revert_sam_single_end.sam";
+    private static final String singleEndSamToRevert = REVERT_SAM_LOCAL_TEST_DATA_DIR + "revert_sam_single_end.sam";
     private static final File hardClipFasta = new File("testdata/picard/sam/MergeBamAlignment/cliptest.fasta");
     private static final File hardClippedAlignedSam = new File("testdata/picard/sam/MergeBamAlignment/hardclip.aligned.sam");
     private static final File hardClippedUnmappedSam = new File("testdata/picard/sam/MergeBamAlignment/hardclip.unmapped.sam");
 
-    private static final String revertedQualities  =
-        "11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111";
+    private static final String revertedQualities =
+            "11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111";
 
     private static final String unmappedRead = "both_reads_present_only_first_aligns/2";
 
@@ -194,7 +209,7 @@ public class RevertSamTest extends CommandLineProgramTest {
         final String args[] = { "INPUT=" + singleEndSamToRevert, "OUTPUT=" + output.getAbsolutePath() };
         runPicardCommandLine(args);
         final ValidateSamFile validator = new ValidateSamFile();
-        validator.INPUT = output;
+        validator.INPUT = new PicardHtsPath(output);
         validator.VALIDATION_STRINGENCY = ValidationStringency.STRICT;
         validator.MODE = ValidateSamFile.Mode.VERBOSE;
         final int result = validator.doWork();
@@ -276,9 +291,9 @@ public class RevertSamTest extends CommandLineProgramTest {
         CloserUtil.close(reader);
     }
 
-    @DataProvider(name="positiveTestData")
+    @DataProvider(name = "positiveTestData")
     public Object[][] getPostitiveTestData() {
-        return new Object[][] {
+        return new Object[][]{
                 {null, true, true, true, true, true, null, null, Collections.EMPTY_LIST},
                 {SAMFileHeader.SortOrder.queryname, true, true, true, true, false, "Hey,Dad!", null, Arrays.asList("XT")},
                 {null, false, true, true, false, false, "Hey,Dad!", "NewLibraryName", Arrays.asList("XT")},
@@ -286,7 +301,7 @@ public class RevertSamTest extends CommandLineProgramTest {
         };
     }
 
-    @Test(dataProvider="overrideTestData", expectedExceptions = {PicardException.class})
+    @Test(dataProvider = "overrideTestData", expectedExceptions = {PicardException.class})
     public void testSampleLibraryOverride(final String sample, final String library) throws Exception {
 
         final File output = File.createTempFile("bad", ".sam");
@@ -305,9 +320,9 @@ public class RevertSamTest extends CommandLineProgramTest {
         Assert.fail("Negative test should have thrown an exception and didn't");
     }
 
-    @DataProvider(name="overrideTestData")
+    @DataProvider(name = "overrideTestData")
     public Object[][] getNegativeTestData() {
-        return new Object[][] {
+        return new Object[][]{
                 {"NewSample", null},
                 {null, "NewLibrary"},
                 {"NewSample", "NewLibrary"}
@@ -363,30 +378,30 @@ public class RevertSamTest extends CommandLineProgramTest {
 
     @Test
     public void testValidateOutputParamsByReadGroupMapValid() {
-        final List<String> errors = new ArrayList<String>();
-        RevertSam.ValidationUtil.validateOutputParamsByReadGroup(null, validOutputMap, errors);
+        final List<String> errors = new ArrayList<>();
+        RevertSam.ValidationUtil.validateOutputParamsByReadGroup(null, new PicardHtsPath(validOutputMap), errors);
         Assert.assertEquals(errors.size(), 0);
     }
 
     @Test
     public void testValidateOutputParamsByReadGroupMissingMap() {
-        final List<String> errors = new ArrayList<String>();
-        RevertSam.ValidationUtil.validateOutputParamsByReadGroup(null, nonExistentOutputMap, errors);
+        final List<String> errors = new ArrayList<>();
+        RevertSam.ValidationUtil.validateOutputParamsByReadGroup(null, new PicardHtsPath(nonExistentOutputMap), errors);
         Assert.assertEquals(errors.size(), 1);
         Assert.assertEquals(errors.get(0).contains("Cannot read"), true);
     }
 
     @Test
     public void testValidateOutputParamsByReadGroupBadHeaderMap() {
-        final List<String> errors = new ArrayList<String>();
-        RevertSam.ValidationUtil.validateOutputParamsByReadGroup(null, badHeaderOutputMap, errors);
+        final List<String> errors = new ArrayList<>();
+        RevertSam.ValidationUtil.validateOutputParamsByReadGroup(null, new PicardHtsPath(badHeaderOutputMap), errors);
         Assert.assertEquals(errors.size(), 1);
         Assert.assertEquals(errors.get(0).contains("Invalid header"), true);
     }
 
     @Test
     public void testValidateOutputParamsByReadGroupNoMapOrDir() {
-        final List<String> errors = new ArrayList<String>();
+        final List<String> errors = new ArrayList<>();
         RevertSam.ValidationUtil.validateOutputParamsByReadGroup(null, null, errors);
         Assert.assertEquals(errors.size(), 1);
         Assert.assertEquals(errors.get(0).contains("Must provide either"), true);
@@ -394,21 +409,21 @@ public class RevertSamTest extends CommandLineProgramTest {
 
     @Test
     public void testValidateOutputParamsByReadGroupDirValid() {
-        final List<String> errors = new ArrayList<String>();
-        RevertSam.ValidationUtil.validateOutputParamsByReadGroup(samTestData, null, errors);
+        final List<String> errors = new ArrayList<>();
+        RevertSam.ValidationUtil.validateOutputParamsByReadGroup(new PicardHtsPath(samTestData), null, errors);
         Assert.assertEquals(errors.size(), 0);
     }
 
     @Test
     public void testValidateOutputParamsNotByReadGroupValid() {
-        final List<String> errors = new ArrayList<String>();
-        RevertSam.ValidationUtil.validateOutputParamsNotByReadGroup(writablePath, null, errors);
+        final List<String> errors = new ArrayList<>();
+        RevertSam.ValidationUtil.validateOutputParamsNotByReadGroup(new PicardHtsPath(writablePath), null, errors);
         Assert.assertEquals(errors.size(), 0);
     }
 
     @Test
     public void testValidateOutputParamsNotByReadGroupNoOutput() {
-        final List<String> errors = new ArrayList<String>();
+        final List<String> errors = new ArrayList<>();
         RevertSam.ValidationUtil.validateOutputParamsNotByReadGroup(null, null, errors);
         Assert.assertEquals(errors.size(), 1);
         Assert.assertEquals(errors.get(0).contains("OUTPUT is required"), true);
@@ -416,8 +431,8 @@ public class RevertSamTest extends CommandLineProgramTest {
 
     @Test
     public void testValidateOutputParamsNotByReadGroupMap() {
-        final List<String> errors = new ArrayList<String>();
-        RevertSam.ValidationUtil.validateOutputParamsNotByReadGroup(null, validOutputMap, errors);
+        final List<String> errors = new ArrayList<>();
+        RevertSam.ValidationUtil.validateOutputParamsNotByReadGroup(null, new PicardHtsPath(validOutputMap), errors);
         Assert.assertEquals(errors.size(), 2);
         Assert.assertEquals(errors.get(0).contains("Cannot provide OUTPUT_MAP"), true);
         Assert.assertEquals(errors.get(1).contains("OUTPUT is required"), true);
@@ -425,8 +440,8 @@ public class RevertSamTest extends CommandLineProgramTest {
 
     @Test
     public void testValidateOutputParamsNotByReadGroupDir() {
-        final List<String> errors = new ArrayList<String>();
-        RevertSam.ValidationUtil.validateOutputParamsNotByReadGroup(samTestData, null, errors);
+        final List<String> errors = new ArrayList<>();
+        RevertSam.ValidationUtil.validateOutputParamsNotByReadGroup(new PicardHtsPath(samTestData), null, errors);
         Assert.assertEquals(errors.size(), 1);
         Assert.assertEquals(errors.get(0).contains("should not be a directory"), true);
     }
@@ -436,9 +451,9 @@ public class RevertSamTest extends CommandLineProgramTest {
         final SAMReadGroupRecord rg1 = new SAMReadGroupRecord("rg1");
         final SAMReadGroupRecord rg2 = new SAMReadGroupRecord("rg2");
 
-        final Map<String, File> outputMap = new HashMap<String, File>();
-        outputMap.put("rg1", new File("/foo/bar/rg1.bam"));
-        outputMap.put("rg2", new File("/foo/bar/rg2.bam"));
+        final Map<String, Path> outputMap = new HashMap<>();
+        outputMap.put("rg1", Paths.get("/foo/bar/rg1.bam"));
+        outputMap.put("rg2", Paths.get("/foo/bar/rg2.bam"));
         RevertSam.ValidationUtil.assertAllReadGroupsMapped(outputMap, Arrays.asList(rg1, rg2));
         RevertSam.ValidationUtil.assertAllReadGroupsMapped(outputMap, Arrays.asList(rg1));
         RevertSam.ValidationUtil.assertAllReadGroupsMapped(outputMap, Arrays.asList(rg2));
@@ -450,9 +465,9 @@ public class RevertSamTest extends CommandLineProgramTest {
         final SAMReadGroupRecord rg2 = new SAMReadGroupRecord("rg2");
         final SAMReadGroupRecord rg3 = new SAMReadGroupRecord("rg3");
 
-        final Map<String, File> outputMap = new HashMap<String, File>();
-        outputMap.put("rg1", new File("/foo/bar/rg1.bam"));
-        outputMap.put("rg2", new File("/foo/bar/rg2.bam"));
+        final Map<String, Path> outputMap = new HashMap<>();
+        outputMap.put("rg1", Paths.get("/foo/bar/rg1.bam"));
+        outputMap.put("rg2", Paths.get("/foo/bar/rg2.bam"));
         RevertSam.ValidationUtil.assertAllReadGroupsMapped(outputMap, Arrays.asList(rg1, rg2, rg3));
     }
 
@@ -473,16 +488,16 @@ public class RevertSamTest extends CommandLineProgramTest {
         final SAMReadGroupRecord rg1 = new SAMReadGroupRecord("rg1");
         final SAMReadGroupRecord rg2 = new SAMReadGroupRecord("rg2");
 
-        final Map<String, File> outputMap = RevertSam.createOutputMap(null, new File("/foo/bar"), ".bam", Arrays.asList(rg1, rg2));
-        Assert.assertEquals(outputMap.get("rg1"), new File("/foo/bar/rg1.bam"));
-        Assert.assertEquals(outputMap.get("rg2"), new File("/foo/bar/rg2.bam"));
+        final Map<String, Path> outputMap = RevertSam.createOutputMapFromReadGroups(Arrays.asList(rg1, rg2), Paths.get("/foo/bar"), ".bam");
+        Assert.assertEquals(outputMap.get("rg1"), Paths.get("/foo/bar/rg1.bam"));
+        Assert.assertEquals(outputMap.get("rg2"), Paths.get("/foo/bar/rg2.bam"));
     }
 
     @Test
     public void testFilePathsWithMapFile() {
-        final Map<String, File> outputMap = RevertSam.createOutputMap(validOutputMap, null, ".bam", Collections.emptyList());
-        Assert.assertEquals(outputMap.get("rg1"), new File("/path/to/my_rg_1.ubam"));
-        Assert.assertEquals(outputMap.get("rg2"), new File("/path/to/my_rg_2.ubam"));
+        final Map<String, Path> outputMap = RevertSam.readOutputMap(validOutputMap.toPath());
+        Assert.assertEquals(outputMap.get("rg1"), Paths.get("/path/to/my_rg_1.ubam"));
+        Assert.assertEquals(outputMap.get("rg2"), Paths.get("/path/to/my_rg_2.ubam"));
     }
 
     @Test
@@ -495,7 +510,7 @@ public class RevertSamTest extends CommandLineProgramTest {
 
     @Test(expectedExceptions = PicardException.class)
     public void testNoRgInfoOutputByRg() {
-        final String [] args = new String[]{
+        final String[] args = new String[]{
                 "I=testdata/picard/sam/bam2fastq/paired/bad/missing-rg-info.sam",
                 "OUTPUT_BY_READGROUP=true",
                 "O=."
@@ -507,7 +522,7 @@ public class RevertSamTest extends CommandLineProgramTest {
     public void testNoRgInfoSanitize() throws Exception {
         final File output = File.createTempFile("no-rg-reverted", ".sam");
         output.deleteOnExit();
-        final String [] args = new String[]{
+        final String[] args = new String[]{
                 "I=testdata/picard/sam/bam2fastq/paired/bad/missing-rg-info.sam",
                 "SANITIZE=true",
                 "O=" + output.getAbsolutePath()
@@ -518,11 +533,11 @@ public class RevertSamTest extends CommandLineProgramTest {
 
     @Test
     public void testSanitizeAndDeduplicateRecords() throws Exception {
-        final File input  = File.createTempFile("test-input-santize-and-deduplicate-records", ".sam");
+        final File input = File.createTempFile("test-input-santize-and-deduplicate-records", ".sam");
         final File output = File.createTempFile("test-output-santize-and-deduplicate-records", ".sam");
 
         // Create a SAM file that has duplicate records
-        final SamReader reader     = SamReaderFactory.makeDefault().open(Paths.get(basicSamToRevert));
+        final SamReader reader = SamReaderFactory.makeDefault().open(Paths.get(basicSamToRevert));
         final SAMFileWriter writer = new SAMFileWriterFactory().makeSAMOrBAMWriter(reader.getFileHeader(), false, input);
         int numDuplicated = 0;
         for (final SAMRecord rec : reader) {
@@ -538,7 +553,7 @@ public class RevertSamTest extends CommandLineProgramTest {
         // Make sure some records are duplicated
         Assert.assertTrue(numDuplicated > 0);
 
-        final String [] args = new String[]{
+        final String[] args = new String[]{
                 "I=" + input.getAbsolutePath(),
                 "SANITIZE=true",
                 "KEEP_FIRST_DUPLICATE=true",
@@ -556,26 +571,26 @@ public class RevertSamTest extends CommandLineProgramTest {
 
         final File outputMBA = File.createTempFile("test-output-hard-clipped-round-trip-mba", ".sam");
         outputMBA.deleteOnExit();
-        final String [] mergeBamAlignmentsArgs = new String[] {
-           "UNMAPPED_BAM=" + hardClippedUnmappedSam.getAbsolutePath(),
-           "ALIGNED_BAM=" + hardClippedAlignedSam.getAbsolutePath(),
-           "OUTPUT=" + outputMBA.getAbsolutePath(),
-           "REFERENCE_SEQUENCE=" + hardClipFasta.getAbsolutePath(),
-           "HARD_CLIP_OVERLAPPING_READS=true"
+        final String[] mergeBamAlignmentsArgs = new String[]{
+            "UNMAPPED_BAM=" + hardClippedUnmappedSam.getAbsolutePath(),
+            "ALIGNED_BAM=" + hardClippedAlignedSam.getAbsolutePath(),
+            "OUTPUT=" + outputMBA.getAbsolutePath(),
+            "REFERENCE_SEQUENCE=" + hardClipFasta.getAbsolutePath(),
+            "HARD_CLIP_OVERLAPPING_READS=true"
         };
         Assert.assertEquals(runPicardCommandLine("MergeBamAlignment", mergeBamAlignmentsArgs), 0);
 
         final File outputRevert = File.createTempFile("test-output-hard-clipped-round-trip-reverted", ".sam");
         outputRevert.deleteOnExit();
-        final String [] revertSamArgs = new String[] {
+        final String[] revertSamArgs = new String[]{
                 "I=" + outputMBA.getAbsolutePath(),
                 "RESTORE_HARDCLIPS=true",
                 "O=" + outputRevert.getAbsolutePath()
         };
         Assert.assertEquals(runPicardCommandLine("RevertSam", revertSamArgs), 0);
 
-        try(SamReader revertedReader = SamReaderFactory.makeDefault().referenceSequence(referenceFasta).open(outputRevert);
-            SamReader unmappedReader = SamReaderFactory.makeDefault().referenceSequence(referenceFasta).open(hardClippedUnmappedSam)) {
+        try (SamReader revertedReader = SamReaderFactory.makeDefault().referenceSequence(referenceFasta).open(outputRevert);
+             SamReader unmappedReader = SamReaderFactory.makeDefault().referenceSequence(referenceFasta).open(hardClippedUnmappedSam)) {
             final SAMRecordIterator revertedIterator = revertedReader.iterator();
             final SAMRecordIterator unmappedIterator = unmappedReader.iterator();
 
@@ -591,4 +606,186 @@ public class RevertSamTest extends CommandLineProgramTest {
             }
         }
     }
+
+    private final static boolean OUTPUT_BY_READ_GROUP = true;
+    @DataProvider(name = "cloudTestData")
+    public Object[][] getCloudTestData() {
+        final PicardHtsPath tempCloudCram = PicardBucketUtils.getTempFilePath(DEFAULT_CLOUD_TEST_OUTPUT_DIR, "RevertSam", ".cram");
+        final PicardHtsPath tempLocalCram = PicardBucketUtils.getLocalTempFilePath("RevertSam", ".cram");
+        return new Object[][]{
+                // Output by read group without the output map, write output bams in the cloud.
+                {NA12878_MEDIUM_GCLOUD, PicardBucketUtils.getRandomGCSDirectory(DEFAULT_CLOUD_TEST_OUTPUT_RELATIVE_PATH), OUTPUT_BY_READ_GROUP, null, null },
+                // Output by read group using the output map, write output bams in the cloud
+                {NA12878_MEDIUM_GCLOUD, null, OUTPUT_BY_READ_GROUP, DEFAULT_CLOUD_TEST_OUTPUT_DIR.getURIString(), null },
+                // Output by read group using the local output map, write output bams in the cloud
+                {NA12878_MEDIUM_GCLOUD, null, OUTPUT_BY_READ_GROUP, REVERT_SAM_LOCAL_TEST_DATA_DIR, null },
+                // Cram input, output a CRAM for each read group
+                {NA12878_MEDIUM_CRAM_GCLOUD, null, OUTPUT_BY_READ_GROUP, DEFAULT_CLOUD_TEST_OUTPUT_DIR.getURIString(), HG19_CHR2021 },
+                // Cram input in the cloud, single cloud cram output
+                {NA12878_MEDIUM_CRAM_GCLOUD, tempCloudCram, !OUTPUT_BY_READ_GROUP, null, HG19_CHR2021 },
+                // Cram input in the cloud, single local cram output
+                {NA12878_MEDIUM_CRAM_GCLOUD, tempLocalCram, !OUTPUT_BY_READ_GROUP, null, HG19_CHR2021 }};
+    }
+
+    /**
+     *
+     * Write the output map for RevertSam based on the read groups present in the header file of the given SAM file.
+     *
+     * @param sam        The read names in the header of this sam file will be used as rows
+     * @param perReadGroupPathBase This path will be the base name of the SAM files listed in the outputMap table.
+     *                   Not to be confused with the location of the table file (the return value of this method).
+     * @return The PicardHtsPath to the tsv with each row a pair (read name, output), where output points to a temp file
+     * created in the directory specified in outputBase.
+     *
+     * Also see RevertSam::createOutputMapFromReadGroups(), which does part of what this method does (creates a dictionary rather than two lists).
+     */
+    private PicardHtsPath getTmpTestReadGroupMapTable(final IOPath sam, final String perReadGroupPathBase) {
+        ValidationUtils.validateArg(sam.getExtension().isPresent(), "The variable sam must be a SAM file but is missing an extension: " + sam.getURIString());
+
+        final String samExtension = sam.getExtension().get();
+        final PicardHtsPath perReadGroupTableFile = PicardBucketUtils.getTempFilePath(DEFAULT_CLOUD_TEST_OUTPUT_DIR.getURIString(), ".txt");
+        final List<String> readGroups = getReadGroups(sam.toPath()).stream().map(rg -> rg.getId()).collect(Collectors.toList());
+        final List<String> readGroupOutput = new ArrayList<>();
+
+        for (String readGroup : readGroups){
+            final PicardHtsPath readGroupOutputPath = PicardBucketUtils.getTempFilePath(perReadGroupPathBase, readGroup, samExtension);
+            readGroupOutput.add(readGroupOutputPath.getURIString());
+        }
+
+        writeOutputMapToFile(perReadGroupTableFile.toPath(), readGroups, readGroupOutput);
+        return perReadGroupTableFile;
+    }
+
+    /**
+     *
+     * Write an output map i.e. tab-delimited pairs (read name, file name) to outputTablePath
+     *
+     * @param outputTablePath The Path to the file where the table is to be written.
+     * @param readGroupNames The list of ordered read names, to be matched with the output files by index.
+     * @param outputFiles The list of ordered names of the output files.
+     */
+    private static void writeOutputMapToFile(final Path outputTablePath, final List<String> readGroupNames, final List<String> outputFiles) {
+        ValidationUtils.validateArg(readGroupNames.size() == outputFiles.size(), "readGroupNames and output files must be the same size but got: " + readGroupNames.size() + " and " + outputFiles.size());
+        try (PrintWriter writer = new PrintWriter(Files.newBufferedWriter(outputTablePath))) {
+            // Write header
+            writeRow(writer, RevertSam.READ_GROUP_ID_COLUMN_NAME, RevertSam.OUTPUT_COLUMN_NAME);
+
+            for (int i = 0; i < readGroupNames.size(); i++){
+                writeRow(writer, readGroupNames.get(i), outputFiles.get(i));
+            }
+        } catch (IOException e) {
+            throw new PicardException("Error writing a tsv file to " + outputTablePath, e);
+        }
+    }
+
+    // Write to a file (writer) the given array of strings as a tab-delimited row
+    private static void writeRow(final PrintWriter writer, final String... row) {
+        final int delimiter = '\t';
+        for (int j = 0; j < row.length; j++){
+            writer.write(row[j]);
+            if (j < row.length - 1) {
+                writer.write(delimiter);
+            } else {
+                writer.println();
+            }
+        }
+    }
+
+    private List<SAMReadGroupRecord> getReadGroups(final Path sam){
+        final List<SAMReadGroupRecord> readGroupsInInput = SamReaderFactory.makeDefault().open(sam).getFileHeader().getReadGroups();
+        return readGroupsInInput;
+    }
+
+    /***
+     *
+     * @param inputSAM The path to the input SAM file
+     * @param outputPath The path to a directory, when output by read group is true and the map isn't provided.
+     *                   The path to a single output SAM file, when output by read group is turned off. May be null.
+     * @param outputByReadGroup Whether to output by read group
+     * @param outputMapDir The location for a dynamically created output map file. May be null.
+     */
+    @Test(dataProvider = "cloudTestData", groups = "cloud")
+    public void testCloud(final PicardHtsPath inputSAM, final PicardHtsPath outputPath, final boolean outputByReadGroup,
+                          final String outputMapDir, final PicardHtsPath reference) {
+        final List<String> args = new ArrayList<>(Arrays.asList(
+                "INPUT=" + inputSAM.getURIString(),
+                "OUTPUT_BY_READGROUP=" + outputByReadGroup));
+
+        if (outputPath != null){
+            args.add("OUTPUT=" + outputPath.getURIString());
+        }
+
+        PicardHtsPath outputMap = null;
+        if (outputMapDir != null){
+            // Dynamically create a temporary output map file based on the read groups in inputSAM.
+            outputMap = getTmpTestReadGroupMapTable(inputSAM, outputMapDir);
+            args.add("OUTPUT_MAP=" + outputMap.getURIString());
+        }
+
+        if (inputSAM.isCram()){
+            Utils.nonNull(reference, () -> "A reference must also be supplied with a CRAM input");
+            args.add("REFERENCE_SEQUENCE=" + reference.getURIString());
+        }
+
+        Assert.assertEquals(runPicardCommandLine(args), 0);
+
+        //                     |Output by Read Group|
+        //                    /                    \
+        //                  YES                    NO
+        //                  /                        \
+        //             |OUTPUT_MAP provided?|    |OUTPUT={file}|
+        //               /                \       *** Case 1 ***
+        //             YES                NO
+        //             /                    \
+        //     |OUTPUT_MAP={map}|    |OUTPUT={directory}|
+        //       *** Case 3 ***         *** Case 2 ***
+
+        // Collect read groups in the input SAM file to compare with the output read groups.
+        final List<SAMReadGroupRecord> readGroupsInInput = SamReaderFactory.makeDefault().open(inputSAM.toPath()).getFileHeader().getReadGroups();
+
+        if (!outputByReadGroup){
+            // *** Case 1: Single output file ***
+            ValidationUtils.validateArg(outputPath != null, "outputPath must be provided and point to a SAM file to be created.");
+            final List<SAMReadGroupRecord> readGroupsInOutput = SamReaderFactory.makeDefault().open(outputPath.toPath()).getFileHeader().getReadGroups();
+            Assert.assertEquals(readGroupsInOutput, readGroupsInInput);
+        } else if (outputMapDir == null){
+            // *** Case 2: OUTPUT_BY_READ_GROUP=true, but OUTPUT_MAP was not provided. ***
+            ValidationUtils.validateArg(outputPath != null, "outputPath must be provided.");
+
+            // Confirm that the expected output files have been created in the directory specified by outputPath
+            final Map<String, Path> expectedOutputPaths = RevertSam.createOutputMapFromReadGroups(readGroupsInInput, outputPath.toPath(), RevertSam.getDefaultExtension(inputSAM.getURIString()));
+
+            for (Map.Entry<String, Path> entry : expectedOutputPaths.entrySet()){
+                final Path outputFile = entry.getValue();
+                Assert.assertTrue(Files.exists(outputFile));
+                final List<SAMReadGroupRecord> readGroups = SamReaderFactory.makeDefault().open(outputFile).getFileHeader().getReadGroups();
+                Assert.assertEquals(readGroups.size(), 1);
+                Assert.assertEquals(readGroups.get(0).getId(), entry.getKey());
+
+                // We must mark these output files to be deleted manually, because we cannot designate them to be temp files
+                if (Files.exists(entry.getValue())){
+                    PicardIOUtils.deleteOnExit(outputFile);
+                }
+            }
+        } else {
+            // *** Case 3: OUTPUT_BY_READ_GROUP=true and outputMap was provided ***
+            try (final TabbedInputParser intermediateParser = new TabbedInputParser(false, Files.newInputStream(outputMap.toPath()));
+                 final TabbedTextFileWithHeaderParser parser = new TabbedTextFileWithHeaderParser(intermediateParser)){
+                final Iterator<TabbedTextFileWithHeaderParser.Row> rowIterator = parser.iterator();
+                while (rowIterator.hasNext()){
+                    final TabbedTextFileWithHeaderParser.Row row = rowIterator.next();
+                    final String readGroup = row.getField(RevertSam.READ_GROUP_ID_COLUMN_NAME);
+                    final String outputForReadGroup = row.getField(RevertSam.OUTPUT_COLUMN_NAME);
+                    final PicardHtsPath outputForReadGroupPath = new PicardHtsPath(outputForReadGroup);
+                    Assert.assertTrue(Files.exists(outputForReadGroupPath.toPath()), "The expected output file does not exist: " +  outputForReadGroup);
+
+                    final List<SAMReadGroupRecord> readGroupsInOutput = SamReaderFactory.makeDefault().open(outputForReadGroupPath.toPath()).getFileHeader().getReadGroups();
+                    Assert.assertEquals(readGroupsInOutput.size(), 1);
+                    Assert.assertEquals(readGroupsInOutput.get(0).getId(), readGroup);
+                }
+            } catch (IOException e){
+                throw new PicardException("Encountered an exception while parsing the output map", e);
+            }
+        }
+    }
 }
